@@ -7,6 +7,7 @@ use Pcore::AE::Handle;
 use AnyEvent::Util qw[portable_socketpair];
 use Pcore::Util::Scalar qw[weaken];
 use if $MSWIN, 'Win32API::File';
+use Pcore::Util::Data qw[:CONST];
 
 has proc => ( is => 'ro', isa =>, InstanceOf ['Pcore::Util::PM::Proc'], init_arg => undef );
 has pid => ( is => 'ro', isa => Int, init_arg => undef );    # real RPC process PID, reported in handshake
@@ -38,34 +39,20 @@ around new => sub ( $orig, $self, @ ) {
         }
     };
 
-    my $boot_args = {
-        script => {
-            path    => $ENV->{SCRIPT_PATH},
-            version => $main::VERSION->normal,
-        },
-        class     => $args{class},
-        buildargs => $args{buildargs},
-        scan_deps => $args{scan_deps},
-    };
+    my $boot_args = [ $ENV->{SCRIPT_PATH}, $main::VERSION->normal, $args{scan_deps} ];
 
     if ($MSWIN) {
-        $boot_args->{ipc} = {
-            in  => Win32API::File::FdGetOsFHandle( fileno $in_r ),
-            out => Win32API::File::FdGetOsFHandle( fileno $out_w ),
-        };
+        push $boot_args->@*, Win32API::File::FdGetOsFHandle( fileno $in_r ), Win32API::File::FdGetOsFHandle( fileno $out_w );
     }
     else {
         fcntl $in_r,  Fcntl::F_SETFD, fcntl( $in_r,  Fcntl::F_GETFD, 0 ) & ~Fcntl::FD_CLOEXEC or die;
         fcntl $out_w, Fcntl::F_SETFD, fcntl( $out_w, Fcntl::F_GETFD, 0 ) & ~Fcntl::FD_CLOEXEC or die;
 
-        $boot_args->{ipc} = {
-            in  => fileno $in_r,
-            out => fileno $out_w,
-        };
+        push $boot_args->@*, fileno $in_r, fileno $out_w;
     }
 
     # serialize CBOR + HEX
-    $boot_args = P->data->to_cbor( $boot_args, encode => 2 )->$*;
+    $boot_args = P->data->to_cbor( $boot_args, encode => $DATA_ENC_B64 )->$*;
 
     my $cmd = [];
 
@@ -90,6 +77,9 @@ around new => sub ( $orig, $self, @ ) {
 
             # wrap AE handles and perform handshale
             $self->_handshake(
+                {   class     => $args{class},
+                    buildargs => $args{buildargs},
+                },
                 sub {
                     $args{on_ready}->($self);
 
@@ -104,7 +94,7 @@ around new => sub ( $orig, $self, @ ) {
     return;
 };
 
-sub _handshake ( $self, $cb ) {
+sub _handshake ( $self, $init, $cb ) {
     weaken $self;
 
     # wrap IN
@@ -131,10 +121,24 @@ sub _handshake ( $self, $cb ) {
     $self->{out}->push_read(
         line => "\x00",
         sub ( $h, $line, $eol ) {
-            if ( $line =~ /\AREADY(\d+)\z/sm ) {
+            if ( $line =~ /\AREADY1(\d+)\z/sm ) {
                 $self->{pid} = $1;
 
-                $cb->();
+                my $cbor = P->data->to_cbor($init);
+
+                $self->{in}->push_write( pack( 'L>', bytes::length $cbor->$* ) . $cbor->$* );
+
+                $self->{out}->push_read(
+                    line => "\x00",
+                    sub ( $h, $line, $eol ) {
+                        if ( $line =~ /\AREADY2(\d+)\z/sm ) {
+                            $cb->();
+                        }
+                        else {
+                            die 'RPC handshake error';
+                        }
+                    }
+                );
             }
             else {
                 die 'RPC handshake error';
@@ -154,7 +158,7 @@ sub _handshake ( $self, $cb ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    2 | 132                  | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |    2 | 122, 132             | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
