@@ -1,13 +1,11 @@
 package Pcore::Util::URI::ftp;    ## no critic qw[NamingConventions::Capitalization]
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::Util::URI];
 
 has '+default_port' => ( default => 21 );
 
-no Pcore;
-
 1;
 __END__
 =pod
